@@ -35,6 +35,17 @@ class BaseLintParser(object):
         norm_path = os.path.normpath(path)
         return os.path.relpath(norm_path, start=self._get_working_dir())
 
+    def _constuct_pr_message(self, linter_message, inline_ignore_message=None):
+        pr_message = linter_message
+        if inline_ignore_message:
+            pr_message += (
+                '\n'
+                '***'  # Horizontal line separator
+                '\n'
+                f'{inline_ignore_message}'
+            )
+        return pr_message
+
 
 class LineRegexParser(BaseLintParser):
     """
@@ -312,6 +323,11 @@ class BanditJSONParser(BaseLintParser):
 
     """
 
+    ignore_instructions = (
+        'Add a `# nosec` comment to this line to silence this alert. '
+        '([Bandit documentation](https://bandit.readthedocs.io/en/latest/config.html#suppressing-individual-lines))'
+    )
+
     def parse_violations(self, output):
 
         output = output.strip()
@@ -321,14 +337,17 @@ class BanditJSONParser(BaseLintParser):
         json_data = json.loads(output)
 
         violations = collections.defaultdict(list)
-        for violation_json in json_data["results"]:
+        linter_violations = json_data.get("results", []) or []
+        for violation_json in linter_violations:
             violation = Violation(
                 line=violation_json["line_number"],
                 column=0,
                 code="{} ({})".format(
                     violation_json["test_id"], violation_json["test_name"]
                 ),
-                message=violation_json["issue_text"],
+                message=self._constuct_pr_message(
+                    violation_json["issue_text"], self.ignore_instructions
+                )
             )
 
             path = self._normalize_path(violation_json["filename"])
@@ -339,6 +358,23 @@ class BanditJSONParser(BaseLintParser):
 
 class CfnNagParser(BaseLintParser):
 
+    ignore_instructions_format = (
+        'To silence this alert, add a `Metadata` block to this resource. '
+        '([cfn_nag documentation](https://github.com/stelligent/cfn_nag#per-resource-rule-suppression))'
+        '\n\n'
+        '<details><summary>Expand to show example</summary>\n\n'
+        '```\n'
+        'Metadata:\n'
+        '  cfn_nag:\n'
+        '    rules_to_suppress:\n'
+        '    - id: {rule_id}\n'
+        '      reason: "Your reason here"\n'
+        '    - id: <another_rule_id>\n'
+        '      reason: "Your reason here"\n'
+        '```\n'
+        '</details>\n'
+    )
+
     def parse_violations(self, output):
 
         file_list = json.loads(output)
@@ -346,13 +382,17 @@ class CfnNagParser(BaseLintParser):
 
         for file in file_list:
             file_violations = []
-            for violation_info in file["file_results"]["violations"]:
+            linter_violations = file.get("file_results", {}).get("violations", []) or []
+            for violation_info in linter_violations:
                 for line_number in violation_info["line_numbers"]:
                     violation = Violation(
                         line=line_number,
                         column=0,
                         code=violation_info["id"],
-                        message=violation_info["message"]
+                        message=self._constuct_pr_message(
+                            violation_info["message"],
+                            self.ignore_instructions_format.format(rule_id=violation_info["id"])
+                        )
                     )
 
                     file_violations.append(violation)
@@ -386,6 +426,11 @@ class GitLeaksParser(BaseLintParser):
 
     """
 
+    ignore_instructions = (
+        'Add a `# nosec` comment to this line to silence this alert. '
+        '([gitleaks config](https://github.com/23andMe/super-linter/blob/main/TEMPLATES/.gitleaks.toml#L171))'
+    )
+
     def parse_violations(self, output):
         if not output:
             return dict()
@@ -398,7 +443,9 @@ class GitLeaksParser(BaseLintParser):
                 line=violation_data["lineNumber"],
                 column=0,
                 code=violation_data["offender"],
-                message=violation_data["rule"]
+                message=self._constuct_pr_message(
+                    violation_data["rule"], self.ignore_instructions
+                )
             )
 
             path = self._normalize_path(violation_data['file'])
@@ -422,6 +469,18 @@ class HadolintParser(BaseLintParser):
 
     """
 
+    ignore_instructions_format = (
+        'To silence this alert, add a '
+        '`hadolint ignore=<rule_id_1>,<rule_id_2>` comment above this line. '
+        '([hadolint documentation](https://github.com/hadolint/hadolint#inline-ignores))'
+        '\n\n'
+        '<details><summary>Expand to show example</summary>\n\n'
+        '```\n'
+        '# hadolint ignore={rule_id}\n'
+        '```\n'
+        '</details>\n'
+    )
+
     def parse_violations(self, output):
         if not output:
             return dict()
@@ -435,7 +494,10 @@ class HadolintParser(BaseLintParser):
                 line=violation_json['line'],
                 column=violation_json['column'],
                 code=violation_json["code"],
-                message=violation_json['message']
+                message=self._constuct_pr_message(
+                    violation_json['message'],
+                    self.ignore_instructions_format.format(rule_id=violation_json["code"])
+                )
             )
 
             path = self._normalize_path(violation_json['file'])
@@ -453,7 +515,7 @@ class TerrascanParser(BaseLintParser):
                 {
                      "rule_name": "apiGatewayName",
                      "description": "Enable AWS CloudWatch Logs for APIs",
-                     "rule_id": "AWS.API Gateway.Logging.Medium.0567",
+                     "rule_id": "AC_AWS_0014",
                      "severity": "MEDIUM",
                      "category": "Logging",
                      "resource_name": "this",
@@ -478,6 +540,21 @@ class TerrascanParser(BaseLintParser):
 
     """
 
+    ignore_instructions_format = (
+        'To silence this alert, add a `ts:skip=<rule_id><reason>` comment inside this resource. '
+        '([Terrascan documentation]'
+        '(https://github.com/accurics/terrascan#how-to-exclude-a-policy-while-scanning-a-resource), '
+        '[rule_id format update]'
+        '(https://github.com/accurics/terrascan/issues/868#issuecomment-865956273))'
+        '\n\n'
+        '<details><summary>Expand to show example</summary>\n\n'
+        '```\n'
+        '# ts:skip={rule_id} Your reason here\n'
+        '# ts:skip=<another_rule_id> Your reason here\n'
+        '```\n'
+        '</details>\n'
+    )
+
     def parse_violations(self, output):
         if not output:
             return dict()
@@ -486,14 +563,16 @@ class TerrascanParser(BaseLintParser):
 
         violations = collections.defaultdict(list)
 
-        for violation_json in json_data["results"]["violations"]:
+        linter_violations = json_data.get("results", {}).get("violations", []) or []
+        for violation_json in linter_violations:
             violation = Violation(
                 line=violation_json['line'],
                 column=0,
-                code="{} ({})".format(
-                    violation_json["rule_id"], violation_json["rule_name"]
-                ),
-                message=violation_json["description"],
+                code=violation_json["rule_id"],
+                message=self._constuct_pr_message(
+                    violation_json["description"],
+                    self.ignore_instructions_format.format(rule_id=violation_json["rule_id"])
+                )
             )
 
             path = self._normalize_path(violation_json["file"])
@@ -591,7 +670,8 @@ class TfsecParser(BaseLintParser):
 
         violations = collections.defaultdict(list)
 
-        for violation_json in json_data["results"]:
+        linter_violations = json_data.get("results", []) or []
+        for violation_json in linter_violations:
             violation = Violation(
                 line=violation_json["location"]["start_line"],
                 column=0,
@@ -647,6 +727,11 @@ class SemgrepParser(BaseLintParser):
     }
     """
 
+    ignore_instructions = (
+        'Add a `nosemgrep` comment to the first line of this finding to silence this alert. '
+        '([semgrep documentation](https://semgrep.dev/docs/ignoring-findings/))'
+    )
+
     def parse_violations(self, output):
         if not output:
             return dict()
@@ -655,12 +740,15 @@ class SemgrepParser(BaseLintParser):
 
         violations = collections.defaultdict(list)
 
-        for violation_json in json_data["results"]:
+        linter_violations = json_data.get("results", []) or []
+        for violation_json in linter_violations:
             violation = Violation(
                 line=violation_json["start"]["line"],
                 column=violation_json["start"]["col"],
                 code=violation_json["check_id"],
-                message=violation_json["extra"]["message"],
+                message=self._constuct_pr_message(
+                    violation_json["extra"]["message"], self.ignore_instructions
+                )
             )
 
             path = self._normalize_path(violation_json["path"])
